==> servicemix-wsn2005-3.3.0.5-fuse-sources.jar: org/apache/servicemix/wsn/jaxws/NotificationConsumerServiceService.java <==

package org.apache.servicemix.wsn.jaxws;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;

@WebServiceClient(targetNamespace = "http://servicemix.apache.org/wsn/jaxws", name = "NotificationConsumerService", wsdlLocation = "file:/home/bsnyder/src/iona/servicemix/tags/servicemix-3.3.0.5-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl")
public class NotificationConsumerServiceService
    extends Service
{

    private static Map ports = new HashMap();
    public static Class NotificationConsumer = org.apache.servicemix.wsn.jaxws.NotificationConsumer.class;

    static {
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), NotificationConsumer);
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationConsumerServiceLocalPort"), NotificationConsumer);
    }

    public NotificationConsumerServiceService()
        throws MalformedURLException
    {
        super(new URL("file:/home/bsnyder/src/iona/servicemix/tags/servicemix-3.3.0.5-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl"), new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationConsumerService"));
    }

    public static Map getPortClassMap() {
        return ports;
    }

    @WebEndpoint(name = "JBI")
    public org.apache.servicemix.wsn.jaxws.NotificationConsumer getJBI() {
        return ((org.apache.servicemix.wsn.jaxws.NotificationConsumer)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), NotificationConsumer));
    }

    @WebEndpoint(name = "NotificationConsumerServiceLocalPort")
    public org.apache.servicemix.wsn.jaxws.NotificationConsumer getNotificationConsumerServiceLocalPort() {
        return ((org.apache.servicemix.wsn.jaxws.NotificationConsumer)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationConsumerServiceLocalPort"), NotificationConsumer));
    }

}

==> servicemix-wsn2005-3.3.0.8-fuse-sources.jar: org/apache/servicemix/wsn/jaxws/NotificationConsumerServiceService.java <==

package org.apache.servicemix.wsn.jaxws;

import java.net.MalformedURLException;
import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import javax.xml.namespace.QName;
import javax.xml.ws.Service;
import javax.xml.ws.WebEndpoint;
import javax.xml.ws.WebServiceClient;

@WebServiceClient(targetNamespace = "http://servicemix.apache.org/wsn/jaxws", name = "NotificationConsumerService", wsdlLocation = "file:/x1/janstey/servicemix-3.3.0-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl")
public class NotificationConsumerServiceService
    extends Service
{

    private static Map ports = new HashMap();
    public static Class NotificationConsumer = org.apache.servicemix.wsn.jaxws.NotificationConsumer.class;

    static {
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), NotificationConsumer);
        ports.put(new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationConsumerServiceLocalPort"), NotificationConsumer);
    }

    public NotificationConsumerServiceService()
        throws MalformedURLException
    {
        super(new URL("file:/x1/janstey/servicemix-3.3.0-fuse/deployables/serviceengines/servicemix-wsn2005/src/main/resources/org/apache/servicemix/wsn/wsn.wsdl"), new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationConsumerService"));
    }

    public static Map getPortClassMap() {
        return ports;
    }

    @WebEndpoint(name = "JBI")
    public org.apache.servicemix.wsn.jaxws.NotificationConsumer getJBI() {
        return ((org.apache.servicemix.wsn.jaxws.NotificationConsumer)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "JBI"), NotificationConsumer));
    }

    @WebEndpoint(name = "NotificationConsumerServiceLocalPort")
    public org.apache.servicemix.wsn.jaxws.NotificationConsumer getNotificationConsumerServiceLocalPort() {
        return ((org.apache.servicemix.wsn.jaxws.NotificationConsumer)(this).getPort(new QName("http://servicemix.apache.org/wsn/jaxws", "NotificationConsumerServiceLocalPort"), NotificationConsumer));
    }

}
